.. Copyright (c) 2018 mudpy authors. Permission to use, copy,
   modify, and distribute this software is granted under terms
   provided in the LICENSE file distributed with this software.

===========
 changelog
===========

.. include:: ../../ChangeLog
   :start-line: 2
